/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.math;

/**
 * Intersection result between a segment and a plane
 * 
 * @author Matthias Betz
 *
 */
public class PlaneSegmentIntersection {

	public enum Type {
		NO_INTERSECTION, IN_PLANE, INTERSECTION_POINT
	}

	private final Type type;
	private final Vector3d point;

	public PlaneSegmentIntersection(Type type, Vector3d point) {
		super();
		this.type = type;
		this.point = point;
	}

	public PlaneSegmentIntersection(Type type){
		if (type == Type.INTERSECTION_POINT){
			throw new IllegalStateException("Tried creating a PlaneSegmentIntersection of type INTERSECTION_POINT" +
					"without an intersection-point vector");
		}
		this.type = type;
		this.point = null;
	}

	public Vector3d getPoint() {
		return point;
	}


	public Type getType() {
		return type;
	}

}
